from core_parser.connection_provider import ConnectionProvider
from airflow.providers.postgres.hooks.postgres import PostgresHook
from psycopg2 import pool

class AirflowPostgresConnectionProvider(ConnectionProvider):
    def __init__(self, conn_id='aws-pg'):
        self.conn_id = conn_id
        self._pool = None
        self._initialize_pool()

    def _initialize_pool(self):
        hook = PostgresHook(postgres_conn_id=self.conn_id)
        # Airflow의 connection 객체 사용: 실제 DSN을 얻기 위해 hide_password=False로 할 수 있음.
        airflow_conn = hook.get_connection(self.conn_id)
        actual_dsn = airflow_conn.get_uri(hide_password=False)
        self._pool = pool.SimpleConnectionPool(
            minconn=1,
            maxconn=10,
            dsn=actual_dsn
        )

    def get_connection(self):
        return self._pool.getconn()

    def release_connection(self, conn):
        self._pool.putconn(conn)
